import React from "react";
import { FileService, TreeNode } from "./type";
export interface FileTreeProps {
    /**
     * 无数据时展示
     */
    emptyRenderer?: () => React.ReactElement;
    /**
     * 渲染节点
     */
    treeItemRenderer?: (treeNode: TreeNode) => React.ReactNode;
    /**
     * 过滤特定节点，如果返回false，列表中不显示
     */
    doFilter?: (treeNode: TreeNode) => boolean;
    /**
     * 点击条目
     */
    onTreeItemClick?: (treeNode: TreeNode) => void;
    /**
     * 打开的目录URI
     */
    rootUri?: string;
    /**
     * 是否支持拖拽
     */
    draggable?: boolean;
    /**
     * 拖拽
     * @param fromUri
     * @param toDirUri
     */
    onDrop?(fromUri: string, toDirUri: string): void;
    /**
     * 右键回调
     */
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>, treeNode: TreeNode) => void;
    /**
     * 文件服务，
     */
    fileService: FileService;
    /**
     * 出错时回调
     */
    onError?: (err: Error) => void;
    /**
     * 目录内文件排序方法
     */
    treeItemSort?: (treeNodes: TreeNode[]) => TreeNode[];
    /**
     * 根目录变化回调
     */
    onRootTreeChange?: (root: TreeNode | undefined) => void;
    /**
     * 子节点缩进尺寸
     */
    indent?: number;
    /**
     *  节点高度，默认30
     */
    rowHeight?: number;
    /**
     * 缩进单位，默认px
     */
    indentUnit?: string;
}
export declare const FileTree: React.ForwardRefExoticComponent<FileTreeProps & React.RefAttributes<{
    getRootNode: () => TreeNode | undefined;
    setRootNode: React.Dispatch<React.SetStateAction<TreeNode | undefined>>;
    getNode: (uri: string) => TreeNode | null | undefined;
    addNode: (uri: string, childNode: TreeNode) => void;
    replaceNode: (uri: string, replacedNode: TreeNode) => void;
    updateNode: (uri: string, record: Partial<TreeNode>) => void;
    removeNode: (uri: string) => void;
    expand: (uri: string, expanded: boolean) => Promise<void>;
    create: (uri: string, childNode: TreeNode) => Promise<void>;
    rename: (uri: string, name: string) => Promise<void>;
    remove: (uri: string) => Promise<void>;
    move: (uri: string, targetDirUri: string) => Promise<void>;
}>>;
